/* this is the easter.cpp renamed easter.c so the original file can remain untouched
    I added the #include "easter.h"
    This as needed to get the prototype with the extern "C"
    I'm not entirely sure I needed to do that but I did it anyway
 */

/* See Meeus,  _Astronomical Algorithms_,  p 67.  He in turn states that
   "the following method has been given by Spencer Jones in his book
   _General Astronomy_ (p 73-74 of the 1922 edition).  It has been
   published again in the _Journal of the British Astronomical Association_,
   vol 88, page 91 (December 1977),  where it is said that it was devised
   in 1876 and appeared in Butcher's _Astronomical Calendar._

      Unlike the formula given by Gauss,  this method has no exception and
   is valid for all years in the Gregorian calendar,  hence from 1583 on."

   I modified the method to include negative years by taking advantage
of the fact that,  in the Gregorian calendar,  Easter recurs on a 5.7
million year cycle. Add 5.7 million to the year,  and all numbers are
positive (as long as year > -5700000,  of course!  I suppose one could
add,  say,  570 million instead,  extending the range to cover roughly
the Paleozoic era to a time 1.5 billion years hence...)

*/


// I wrote the below .h file, but then realized I didn't need it since I didn't want to use the function from C code
// #include "easter.h"

#pragma module(smart_link=>off)    // this lets the linker put unused functions in the OBJ so can find mangled name...sometimes
// extern "Pascal" void easter_date( const long year, int *month, int *day);
   extern "C++" void easter_date( const long year, int *month, int *day);       // Use C++ and put the mangled name in the NAME()

// I created this so mangling would match and I could call from Clarion w/o a NAME()
   #pragma save
   #pragma name(prefix=>"")  //so no leading underscore
   void easter_date( const long year, short *month, short *day);       // Use C++ and put the mangled name in the, extern "C++"
   #pragma restore

void easter_date( const long year, signed *month, int *day)
{
   const long year2 = year + 5700000L;
   const long a = year2 % 19L, b = year2 / 100L, c = year2 % 100L;
   const long d = b / 4L, e = b % 4L, f = (b + 8L) / 25L;
   const long g = (b - f + 1L) / 3L, h = (19L * a + b - d - g + 15L) % 30L;
   const long i = c / 4L, k = c % 4L, l = (32L + e + e + i + i - h - k) % 7L;
   const long m = (a + 11L * h + 22L * l) / 451L, tval = h + l - 7L * m + 114L;

   *month = (int)( tval / 31L);
   *day = (int)( tval % 31L) + 1;
}



void easter_date( const long year, short *month, short *day)
{
   const long year2 = year + 5700000L;
   const long a = year2 % 19L, b = year2 / 100L, c = year2 % 100L;
   const long d = b / 4L, e = b % 4L, f = (b + 8L) / 25L;
   const long g = (b - f + 1L) / 3L, h = (19L * a + b - d - g + 15L) % 30L;
   const long i = c / 4L, k = c % 4L, l = (32L + e + e + i + i - h - k) % 7L;
   const long m = (a + 11L * h + 22L * l) / 451L, tval = h + l - 7L * m + 114L;

   *month = (short)( tval / 31L);
   *day = (short)( tval % 31L) + 1;
}


//Carl: I wrote this to play with Mangling
/* ok I'm not a C programmer...

   extern "C++" void easter_date( const long year, char *month, char *day);       // Use C++ and put the mangled name in the

    void easter_date( const long year, char *month, char *day)
    {
       int i_month, i_day;
       long year2;
       year2 = year;
       easter_date(year2, i_month, i_day);

       *month = (char) i_month;
       *day   = (char) i_day;
    }
*/

#ifdef TEST_CODE

#include <stdio.h>
#include <stdlib.h>

void main( int argc, char **argv)
{
   int month, day;

   easter_date( atol( argv[1]), &month, &day);
   printf( "%d %s", day, (month == 3 ? "March" : "April"));
}
#endif
